local PetBattle = select(2, ...)
local L = PetBattle.L

local Options = {}
local dialog, options
local function loadOptions()
	options = {}
	options.type = "group"
	options.name = L["Pet Battle Tactician"]

	options.args = {}
	options.args.general = {
		order = 1,
		type = "group",
		name = L["General"],
		get = function(info)
			return PetBattle.db.profile[info[#(info)]]
		end,
		set = function(info, value)
			PetBattle.db.profile[info[#(info)]] = value
			PetBattle:Reload()
		end,
		args = {
			general = {
				order = 0,
				type = "group",
				inline = true,
				name = L["General"],
				args = {
					locked = {
						order = 0,
						type = "toggle",
						name = L["Locked"],
						desc = L["Prevents any frames from being moved."],
						width = "full"
					}
				}
			},
		},
	}

	for type, name in pairs({["enemyAbilities"] = L["Enemy"], ["friendlyAbilities"] = L["Friendly"]}) do
		options.args.general.args[type] = {
			type = "group",
			order = 1,
			inline = true,
			name = string.format(L["%s Pet Abilities"], name),
			set = function(info, value)
				PetBattle.db.profile[type][info[#(info)]] = value
				PetBattle:Reload()
			end,
			get = function(info)
				return PetBattle.db.profile[type][info[#(info)]]
			end,
			args = {
				enabled = {
					order = 0,
					type = "toggle",
					name = L["Enabled"],
					desc = string.format(L["Show the %s Pet frames."], name),
					width = "full",
				},
				active = {
					order = 1,
					type = "toggle",
					name = L["Show Active Pet"],
					desc = L["When enabled, the currently active battle pet is shown."]
				},
				inactive = {
					order = 2,
					type = "toggle",
					name = L["Show Inactive Pets"],
					desc = L["When enabled, the inactive pets are shown."]
				},
				scale = {
					order = 3,
					type = "range",
					name = L["Scale"],
					desc = L["How big the frames should be."],
					min = 0.01, max = 2, step = 0.01, isPercent = true,
				},
				alpha = {
					order = 4,
					type = "range",
					name = L["Alpha"],
					desc = L["Frame opacity."],
					min = 0.01, max = 1, step = 0.01, isPercent = true,
				},
			}
		}
	end

	options.args.profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(PetBattle.db)
	options.args.profile.order = 99999
end


SLASH_PETBATTLETACT1 = "/pbt"
SLASH_PETBATTLETACT2 = "/petbattletact"
SLASH_PETBATTLETACT3 = "/petbattletactician"
SlashCmdList["PETBATTLETACT"] = function()
	if( not options ) then
		dialog = LibStub("AceConfigDialog-3.0")
		loadOptions()
		
		LibStub("AceConfig-3.0"):RegisterOptionsTable("PetBattleTactician", options)
		dialog:SetDefaultSize("PetBattleTactician", 650, 500)
	end
	
	dialog:Open("PetBattleTactician")
end
